@@ -44,18 +44,11 @@ __all__ = [
     'setGlobalPrintFullStrings',
     'setGlobalPrintPrivateEntries',
     'str2bytes',
-    'str2unicode',
     'stringtypes',
-    'supportsintenum',
-    'supportsintflag',
-    'supportsksyexport',
-    'supportskwordered',
-    'supportsnumpy',
     'swapbitsinbytes',
     'swapbytes',
     'swapbytesinbits',
     'trimstring',
     'unhexlify',
-    'unicode2str',
     'unicodestringtype',
 ]
